var debugconnectionId = -1;
var RXreadBuffer = "";

function checkSerialClose(){
	if (debugconnectionId != -1) {
      chrome.serial.close(debugconnectionId, ondebugClose);
	  log('Closed port ' + debugconnectionId);
      //return;
    }
};

onload = function() {
  chrome.serial.getPorts(function(ports) {
    buildPortPicker(ports);
  });
};

function buildPortPicker(ports) {
  var eligiblePorts = ports.filter(function(port) {
    return !port.match(/\/dev\/tty/) && port.match(/COM/);
  });
 
  var debugportPicker = document.getElementById('debug-port-picker');
  eligiblePorts.forEach(function(port) {
    var debugportOption = document.createElement('option');
    debugportOption.value = debugportOption.innerText = port;
    debugportPicker.appendChild(debugportOption);
  });

  debugportPicker.onchange = function() {
    if (debugconnectionId != -1) {
      chrome.serial.close(debugconnectionId, ondebugClose);
	  log('Closed port ' + debugconnectionId);
      //return;
    }
    openSelectedDebugPort();
  };
}

function openSelectedDebugPort() {
  var portPicker = document.getElementById('debug-port-picker');
  var selectedPort = portPicker.options[portPicker.selectedIndex].value;
  chrome.serial.open(selectedPort, {bitrate: 230400}, onOpenDebug);
  log('Opened debug port ' + selectedPort);
}

function log(message) {
  document.querySelector('#log').textContent += message + '\n';
  var textarea = document.querySelector('#log');
   if(textarea.selectionStart == textarea.selectionEnd) {
      textarea.scrollTop = textarea.scrollHeight;
   }
};

function logRX(message) {
  document.querySelector('#rx').textContent += message + '\n';
  var textarea = document.querySelector('#rx');
   if(textarea.selectionStart == textarea.selectionEnd) {
      textarea.scrollTop = textarea.scrollHeight;
   }
};

document.querySelector('#send-T').onclick = function() {
  log('Sending T');
  writeSerial("T",debugconnectionId);
};

function onOpenDebug(openInfo) {
  debugconnectionId = openInfo.connectionId;
  log("debugconnectionId: " + debugconnectionId);
  if (debugconnectionId == -1) {
    log('Could not open');
    return;
  }
  else {
    log('Connected');
  
    chrome.serial.setControlSignals(debugconnectionId,{rts:true},function(){});

    chrome.serial.read(debugconnectionId, 1, ondebugRead);
  
    log('Control signals set and reading');
  }
};

function ondebugClose(closeInfo) {
  log("debugconnectionId: " + debugconnectionId);
  debugconnectionId = -1;
  log("Disconnected");
};

function ondebugRead(readInfo) {
  var uint8View = new Uint8Array(readInfo.data);
  var value = String.fromCharCode(uint8View[0]);
    
  if (value == "\n")
  {
      logRX(RXreadBuffer);
	  
	  // get the vlaues from the string
	  var values = RXreadBuffer.split(" ");
	  if (values.length == 3) {
		  //var user = (values[0].trim()).search("1");
		  var user = Number(values[0]);
		  var centerX = Number(values[1])/2;
		  var centerY = Number(values[2])/2;
		  
		  // draw a circle on the canvas
		  var canvas = document.getElementById('drawingCanvas');
		  canvas.width = canvas.width; // clear the canvas
		  var context = canvas.getContext('2d');
		  var radius = 5;

		  context.beginPath();
		  context.arc(centerX, centerY, radius, 0, 2 * Math.PI, false);
		  if (user == 1) {
			context.fillStyle = 'blue';
		  }
		  else {
			context.fillStyle = 'red';
		  }
		  context.fill();
		  context.lineWidth = 1;
		  context.strokeStyle = '#003300';
		  context.stroke();
	  }
	  
      RXreadBuffer = "";
  }
  else
  {
    if(value.charCodeAt() > 0) {
		RXreadBuffer = RXreadBuffer.concat(value);
	}
  }
  // Keep on reading.
  chrome.serial.read(debugconnectionId, 1, ondebugRead);
};

var writeSerial=function(str,conn) {
  chrome.serial.write(conn, str2ab(str), function(){});
};

// Convert string to ArrayBuffer
var str2ab=function(str) {
  var buf=new ArrayBuffer(str.length);
  var bufView=new Uint8Array(buf);
  for (var i=0; i<str.length; i++) {
    bufView[i]=str.charCodeAt(i);
  }
  return buf;
};
